@@ -156,7 +156,7 @@ gnunet_conversation_gtk_contact_list_treeview_row_activated_cb (
  */
 static void
 display_record (void *cls,
-                const struct GNUNET_CRYPTO_EcdsaPrivateKey *zone_key,
+                const struct GNUNET_IDENTITY_PrivateKey *zone_key,
                 const char *rname,
                 unsigned int rd_len,
                 const struct GNUNET_GNSRECORD_Data *rd)
@@ -311,7 +311,7 @@ gnunet_conversation_gtk_contacts_zone_combobox_changed_cb (GtkComboBox *widget,
                                                            gpointer user_data)
 {
   struct GNUNET_IDENTITY_Ego *ego;
-  const struct GNUNET_CRYPTO_EcdsaPrivateKey *temp_zone_pkey;
+  const struct GNUNET_IDENTITY_PrivateKey *temp_zone_pkey;
   const char *tld;
 
   if (NULL != zone_mon)
