@@ -99,17 +99,14 @@ static int private_record;
  * operation.
  *
  * @param cls NULL
- * @param success #GNUNET_SYSERR on failure (including timeout/queue drop/failure to validate)
- *                #GNUNET_NO if content was already there
- *                #GNUNET_YES (or other positive value) on success
- * @param emsg NULL on success, otherwise an error message
+ * @param ec the error code
  */
 static void
-add_contact_continuation (void *cls, int32_t success, const char *emsg)
+add_contact_continuation (void *cls, enum GNUNET_ErrorCode ec)
 {
-  if (GNUNET_YES != success)
+  if (GNUNET_EC_NONE != ec)
     GCG_log (_ ("Adding contact failed: %s\n"),
-             (GNUNET_NO == success) ? _ ("record exists") : emsg);
+             GNUNET_ErrorCode_get_hint (ec));
   add_contact_qe = NULL;
 }
 
@@ -195,18 +192,16 @@ GSC_add_contact (const gchar *name, const gchar *address)
  * add operation.  Finish 'add phone' operation.
  *
  * @param cls closure
- * @param success #GNUNET_SYSERR on failure (including timeout/queue drop/failure to validate)
- *                #GNUNET_NO if content was already there or not found
- *                #GNUNET_YES (or other positive value) on success
- * @param emsg NULL on success, otherwise an error message
+ * @param ec the errro code
  */
 static void
-add_phone_continuation (void *cls, int32_t success, const char *emsg)
+add_phone_continuation (void *cls, enum GNUNET_ErrorCode ec)
 {
   add_phone_qe = NULL;
-  if (GNUNET_SYSERR == success)
+  if (GNUNET_EC_NONE != ec)
   {
-    GCG_log (_ ("Failed to publish my PHONE record: %s\n"), emsg);
+    GCG_log (_ ("Failed to publish my PHONE record: %s\n"),
+             GNUNET_ErrorCode_get_hint (ec));
     GNUNET_free (phone_label);
     phone_label = NULL;
   }
@@ -344,7 +339,7 @@ finish_shutdown ()
   GNUNET_SCHEDULER_add_now (&async_disconnect, NULL);
   GNUNET_free (my_rd_data);
   memset (&my_rd, 0, sizeof (my_rd));
-  GNUNET_CRYPTO_ecdsa_key_clear (&zone_pkey);
+  memset (&zone_pkey, 0, sizeof (zone_pkey));
 }
 
 
@@ -354,17 +349,15 @@ finish_shutdown ()
  * with 'add phone' operation if one is pending.
  *
  * @param cls closure
- * @param success #GNUNET_SYSERR on failure (including timeout/queue drop/failure to validate)
- *                #GNUNET_NO if content was already there or not found
- *                #GNUNET_YES (or other positive value) on success
- * @param emsg NULL on success, otherwise an error message
+ * @param ec the error code
  */
 static void
-remove_phone_continuation (void *cls, int32_t success, const char *emsg)
+remove_phone_continuation (void *cls, enum GNUNET_ErrorCode ec)
 {
   remove_phone_qe = NULL;
-  if (GNUNET_SYSERR == success)
-    GCG_log (_ ("Failed to remove PHONE record: %s\n"), emsg);
+  if (GNUNET_EC_NONE != ec)
+    GCG_log (_ ("Failed to remove PHONE record: %s\n"),
+             GNUNET_ErrorCode_get_hint (ec));
   if (GNUNET_YES == add_waiting)
     add_phone ();
   if (GNUNET_YES == in_shutdown)
