@@ -37,7 +37,7 @@
  * @param data the builder's closure, unused
  */
 void
-GNUNET_GTK_anonymity_spin_button_value_changed_cb (GtkWidget * w, gpointer data)
+GNUNET_GTK_anonymity_spin_button_value_changed_cb (GtkWidget *w, gpointer data)
 {
 #ifdef GdkRBGA
   GtkSpinButton *spin;
@@ -83,13 +83,14 @@ GNUNET_GTK_anonymity_spin_button_value_changed_cb (GtkWidget * w, gpointer data)
  * @return TRUE on success, FALSE on failure
  */
 gboolean
-GNUNET_GTK_select_anonymity_level (GtkBuilder * builder, gchar * combo_name,
+GNUNET_GTK_select_anonymity_level (GtkBuilder *builder,
+                                   gchar *combo_name,
                                    guint sel_level)
 {
   GtkComboBox *combo;
 
   combo = GTK_COMBO_BOX (gtk_builder_get_object (builder, combo_name));
-  if (!combo)
+  if (! combo)
     return FALSE;
   return GNUNET_GTK_select_anonymity_combo_level (combo, sel_level);
 }
@@ -110,13 +111,14 @@ GNUNET_GTK_select_anonymity_combo_level (GtkComboBox *combo, guint sel_level)
   guint level;
 
   model = gtk_combo_box_get_model (combo);
-  if (!model)
+  if (! model)
     return FALSE;
   if (! gtk_tree_model_get_iter_first (model, &iter))
     return FALSE;
   do
   {
-    gtk_tree_model_get (model, &iter,
+    gtk_tree_model_get (model,
+                        &iter,
                         GNUNET_GTK_ANONYMITY_LEVEL_MC_LEVEL,
                         &level,
                         -1);
@@ -125,11 +127,9 @@ GNUNET_GTK_select_anonymity_combo_level (GtkComboBox *combo, guint sel_level)
       gtk_combo_box_set_active_iter (combo, &iter);
       return TRUE;
     }
-  }
-  while (gtk_tree_model_iter_next (model, &iter));
+  } while (gtk_tree_model_iter_next (model, &iter));
   return FALSE;
 }
 
 
-
 /* end of gnunet-fs-gtk-anonymtiy_spin_buttons.c */
