@@ -43,8 +43,10 @@ static void
 beep ()
 {
   gdk_display_beep (gdk_screen_get_display (
-    gdk_window_get_screen (gtk_widget_get_parent_window (GTK_WIDGET (
-      GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_main_window"))))));
+                      gdk_window_get_screen (gtk_widget_get_parent_window (
+                                               GTK_WIDGET (
+                                                 GNUNET_FS_GTK_get_main_window_object (
+                                                   "GNUNET_GTK_main_window"))))));
 }
 
 
@@ -178,7 +180,7 @@ start_search (struct GNUNET_GTK_MainWindowContext *main_ctx)
     GtkTreeIter iter;
 
     mime_combo = GTK_COMBO_BOX (GNUNET_FS_GTK_get_main_window_object (
-      "main_window_search_mime_combobox"));
+                                  "main_window_search_mime_combobox"));
     mime_model = gtk_combo_box_get_model (mime_combo);
     mime_keyword = NULL;
     if ((NULL != mime_model) &&
@@ -198,7 +200,7 @@ start_search (struct GNUNET_GTK_MainWindowContext *main_ctx)
     GtkComboBox *namespace_box;
 
     namespace_box = GTK_COMBO_BOX (GNUNET_FS_GTK_get_main_window_object (
-      "main_window_search_namespace_combobox"));
+                                     "main_window_search_namespace_combobox"));
     nsid = gtk_entry_get_text (
       GTK_ENTRY (gtk_bin_get_child (GTK_BIN (namespace_box))));
     if ((NULL != nsid) && ((0 == strcasecmp (nsid, "<none>")) ||
@@ -362,22 +364,19 @@ abort_pseu_lookup (struct PseuLookupContext *lctx)
  * operation.
  *
  * @param cls closure
- * @param success #GNUNET_SYSERR on failure (including timeout/queue drop/failure to validate)
- *                #GNUNET_NO if content was already there or not found
- *                #GNUNET_YES (or other positive value) on success
- * @param emsg NULL on success, otherwise an error message
+ * @param success the error code
  */
 static void
-store_continuation (void *cls, int32_t success, const char *emsg)
+store_continuation (void *cls, enum GNUNET_ErrorCode success)
 {
   struct PseuLookupContext *lctx = cls;
 
   lctx->qe = NULL;
-  if (NULL != emsg)
+  if (GNUNET_EC_NONE != success)
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                 _ ("Failed to save record: %s\n"),
-                emsg);
+                GNUNET_ErrorCode_get_hint (success));
     beep ();
   }
   abort_pseu_lookup (lctx);
@@ -416,13 +415,15 @@ save_pseudonym_with_nick (struct PseuLookupContext *lctx, const char *nick)
   main_ctx = GNUNET_FS_GTK_get_main_context ();
   lctx->namestore = GNUNET_NAMESTORE_connect (main_ctx->cfg);
   GNUNET_assert (NULL != lctx->namestore);
-  lctx->qe = GNUNET_NAMESTORE_records_store (lctx->namestore,
-                                             main_ctx->sks_zone,
-                                             nick,
-                                             1,
-                                             &rd,
-                                             &store_continuation,
-                                             lctx);
+  lctx->qe =
+    GNUNET_NAMESTORE_records_store (lctx->namestore,
+                                    GNUNET_IDENTITY_ego_get_private_key (
+                                      main_ctx->sks_zone),
+                                    nick,
+                                    1,
+                                    &rd,
+                                    &store_continuation,
+                                    lctx);
 }
 
 
@@ -667,7 +668,7 @@ GNUNET_FS_GTK_save_button_clicked_cb (GtkButton *button, gpointer user_data)
     return;
   }
   widget = GTK_COMBO_BOX (GNUNET_FS_GTK_get_main_window_object (
-    "main_window_search_namespace_combobox"));
+                            "main_window_search_namespace_combobox"));
   text = gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (widget))));
   ret = GNUNET_GNSRECORD_zkey_to_pkey (text, &pkey);
   if (GNUNET_OK != ret)
