@@ -431,6 +431,7 @@ gtk_tree_iter_equals (GtkTreeModel *tm, GtkTreeIter *i1, GtkTreeIter *i2)
   return (0 == ret) ? GNUNET_YES : GNUNET_NO;
 }
 
+
 /**
  * Update selectivity of execute/cancel buttons in the master dialog.
  *
@@ -474,6 +475,7 @@ update_selectivity_execute_cancel (struct MainPublishingDialogContext *ctx)
     gtk_widget_set_sensitive (ctx->cancel_button, FALSE);
 }
 
+
 /**
  * Update selectivity of up/down/left/right buttons in the master dialog.
  *
@@ -546,6 +548,7 @@ update_selectivity_edit (struct MainPublishingDialogContext *ctx)
     gtk_widget_set_sensitive (ctx->up_button, FALSE);
 }
 
+
 /**
  * The selection in the file list tree view changed; update the button
  * sensitivity.
@@ -563,6 +566,7 @@ GNUNET_GTK_master_publish_dialog_file_informatino_treeview_selection_changed_cb
   update_selectivity_edit (ctx);
 }
 
+
 /**
  * Add an empty directory to the tree model.
  *
@@ -631,6 +635,7 @@ create_dir_at_iter (struct MainPublishingDialogContext *ctx,
   update_selectivity_execute_cancel (ctx);
 }
 
+
 /**
  * Copy an entry in the tree from the 'old' position to the 'new'
  * position.  All of the fields are copied, plain pointers will be
@@ -758,6 +763,7 @@ copy_entry (struct MainPublishingDialogContext *ctx,
   }
 }
 
+
 /**
  * Called when global ns publication checkbox is toggled.
  * Adjusts execute/cancel button sensitivity.
@@ -773,6 +779,7 @@ GNUNET_GTK_master_publish_dialog_global_checkbox_toggled_cb (
   update_selectivity_execute_cancel (user_data);
 }
 
+
 /**
  * Called when private ns publication checkbox is toggled.
  * Adjusts execute/cancel button sensitivity.
@@ -788,6 +795,7 @@ GNUNET_GTK_master_publish_dialog_own_checkbox_toggled_cb (
   update_selectivity_execute_cancel (user_data);
 }
 
+
 /**
  * Called when updateability checkbox is toggled.
  * Adjusts execute/cancel button sensitivity.
@@ -803,6 +811,7 @@ GNUNET_GTK_master_publish_dialog_updateable_checkbox_toggled_cb (
   update_selectivity_execute_cancel (user_data);
 }
 
+
 /**
  * Generates an update id from a new id.
  *
@@ -840,6 +849,7 @@ generate_update_id (const gchar *new_text)
   return new_update_id;
 }
 
+
 /**
  * Checks whether existing update id was generated or not.
  * Generates an update id from the previous id, then checks if
@@ -867,6 +877,7 @@ update_id_is_autofilled (const gchar *existing_update_id,
   return result;
 }
 
+
 /**
  * Generates a new update id and fills the entry, if necessary.
  * Stores new identifier as previous_id in the context struct.
@@ -897,6 +908,7 @@ maybe_change_update_id (struct MainPublishingDialogContext *ctx,
   ctx->previous_id = g_strdup (new_text);
 }
 
+
 /**
  * Called when identifier entry contents are changed by anything.
  * Generates a new update id and fills the entry, if necessary.
@@ -920,6 +932,7 @@ GNUNET_GTK_master_publish_dialog_identifier_entry_changed_cb (
   update_selectivity_execute_cancel (ctx);
 }
 
+
 /**
  * The selection in the identifier tree view changed.
  * Copy text into identifier entry, or
@@ -961,6 +974,7 @@ GNUNET_GTK_master_publish_dialog_previous_identifiers_treeview_selection_changed
   g_free (new_text);
 }
 
+
 /**
  * User has clicked on the 'right' button to move files in the master
  * edit dialog tree view.  Execute the move.
@@ -1015,6 +1029,7 @@ GNUNET_GTK_master_publish_dialog_right_button_clicked_cb (GtkWidget *dummy,
                                           &iter);
 }
 
+
 /**
  * User has clicked on the 'left' button to move files in the master
  * edit dialog tree view.  Execute the move.
@@ -1056,6 +1071,7 @@ GNUNET_GTK_master_publish_dialog_left_button_clicked_cb (GtkWidget *dummy,
                                           &iter);
 }
 
+
 /**
  * User has clicked on the 'up' button to move files in the master
  * edit dialog tree view.  Execute the move.
@@ -1116,6 +1132,7 @@ GNUNET_GTK_master_publish_dialog_up_button_clicked_cb (GtkWidget *dummy,
                                           &iter);
 }
 
+
 /**
  * User has clicked on the 'down' button to move files in the master
  * edit dialog tree view.  Execute the move.
@@ -1158,6 +1175,7 @@ GNUNET_GTK_master_publish_dialog_down_button_clicked_cb (GtkWidget *dummy,
                                           &iter);
 }
 
+
 /**
  * User has clicked on the 'new' button to add an empty directory in the master
  * edit dialog tree view.  Add an empty directory.
@@ -1189,6 +1207,7 @@ GNUNET_GTK_master_publish_dialog_new_button_clicked_cb (GtkWidget *dummy,
     create_dir_at_iter (ctx, "unnamed/", &bo, &iter, &pos);
 }
 
+
 /**
  * Free row reference stored in the file information's
  * client-info pointer.
@@ -1225,6 +1244,7 @@ free_fi_row_reference (void *cls,
   return GNUNET_OK;
 }
 
+
 /**
  * User has clicked on the 'delete' button to delete a file or directory in the
  * master edit dialog tree view.  Delete the selected entry.
@@ -1302,6 +1322,7 @@ GNUNET_GTK_master_publish_dialog_delete_button_clicked_cb (GtkWidget *dummy,
   update_selectivity_edit (ctx);
 }
 
+
 /* ******************** progress dialog / import of directories ************* */
 
 /**
@@ -1329,6 +1350,7 @@ destroy_progress_dialog (struct AddDirClientContext *adcc)
   GNUNET_free (adcc);
 }
 
+
 /**
  * User clicked on the 'cancel' button of the progress dialog.
  * Cancel the operation.
@@ -1351,6 +1373,7 @@ GNUNET_FS_GTK_progress_dialog_cancel_button_clicked_cb (GtkButton *button,
   destroy_progress_dialog (adcc);
 }
 
+
 /**
  * User attempted to close the progress dialog.  Refuse.
  *
@@ -1368,6 +1391,7 @@ GNUNET_FS_GTK_progress_dialog_delete_event_cb (GtkWidget *widget,
   return TRUE;
 }
 
+
 /**
  * Display some additional information in the text area of the
  * progress dialog.
@@ -1385,6 +1409,7 @@ insert_progress_dialog_text (struct AddDirClientContext *adcc, const char *text)
                               adcc->textview_vertical_adjustment));
 }
 
+
 /**
  * Convert a single item from the scan to an entry in the tree view.
  *
@@ -1448,14 +1473,15 @@ add_item (struct AddDirClientContext *adcc,
   else
   {
     fi =
-      GNUNET_FS_file_information_create_from_file (GNUNET_FS_GTK_get_fs_handle (),
-                                                   row_reference,
-                                                   item->filename,
-                                                   item->ksk_uri,
-                                                   item->meta,
-                                                   adcc
-                                                     ->directory_scan_do_index,
-                                                   &adcc->directory_scan_bo);
+      GNUNET_FS_file_information_create_from_file (
+        GNUNET_FS_GTK_get_fs_handle (),
+        row_reference,
+        item->filename,
+        item->ksk_uri,
+        item->meta,
+        adcc
+        ->directory_scan_do_index,
+        &adcc->directory_scan_bo);
     file_size_fancy = GNUNET_STRINGS_byte_size_fancy (fsize);
   }
   gtk_tree_store_set (ts,
@@ -1474,13 +1500,14 @@ add_item (struct AddDirClientContext *adcc,
                       fi,
                       PUBLISH_MC_EXPIRATION_TIME_ABSOLUTE,
                       (guint64)
-                        adcc->directory_scan_bo.expiration_time.abs_value_us,
+                      adcc->directory_scan_bo.expiration_time.abs_value_us,
                       PUBLISH_MC_REPLICATION_LEVEL,
                       (guint) adcc->directory_scan_bo.replication_level,
                       -1);
   GNUNET_free (file_size_fancy);
 }
 
+
 /**
  * Recursively traverse the share tree and add it to the tree store
  *
@@ -1509,6 +1536,7 @@ add_share_items_to_treestore (struct AddDirClientContext *adcc,
   }
 }
 
+
 /**
  * Function called when the scanner had some trouble and we
  * need to abort the scanning process (which we need to do
@@ -1529,6 +1557,7 @@ stop_scanner_task (void *cls)
   }
 }
 
+
 /**
  * Progress callback called from the directory scanner with
  * information about our progress scanning the hierarchy.
@@ -1580,8 +1609,8 @@ directory_scan_cb (void *cls,
                      filename);
 #if ! VERBOSE_PROGRESS
     gtk_widget_show (GTK_WIDGET (
-      gtk_builder_get_object (adcc->progress_dialog_builder,
-                              "GNUNET_FS_GTK_progress_dialog_scrolled_window")));
+                       gtk_builder_get_object (adcc->progress_dialog_builder,
+                                               "GNUNET_FS_GTK_progress_dialog_scrolled_window")));
 #endif
     insert_progress_dialog_text (adcc, s);
     GNUNET_free (s);
@@ -1625,23 +1654,24 @@ directory_scan_cb (void *cls,
     }
     break;
   case GNUNET_FS_DIRSCANNER_FINISHED: {
-    struct GNUNET_FS_ShareTreeItem *directory_scan_result;
+      struct GNUNET_FS_ShareTreeItem *directory_scan_result;
 
-    insert_progress_dialog_text (adcc, _ ("Scanner has finished.\n"));
-    directory_scan_result = GNUNET_FS_directory_scan_get_result (adcc->ds);
-    adcc->ds = NULL;
-    GNUNET_FS_share_tree_trim (directory_scan_result);
-    add_share_items_to_treestore (adcc, directory_scan_result, NULL);
-    GNUNET_FS_share_tree_free (directory_scan_result);
-    destroy_progress_dialog (adcc);
-  }
-  break;
+      insert_progress_dialog_text (adcc, _ ("Scanner has finished.\n"));
+      directory_scan_result = GNUNET_FS_directory_scan_get_result (adcc->ds);
+      adcc->ds = NULL;
+      GNUNET_FS_share_tree_trim (directory_scan_result);
+      add_share_items_to_treestore (adcc, directory_scan_result, NULL);
+      GNUNET_FS_share_tree_free (directory_scan_result);
+      destroy_progress_dialog (adcc);
+    }
+    break;
   default:
     GNUNET_break (0);
     break;
   }
 }
 
+
 /**
  * Setup the context and progress dialog for scanning a file or
  * directory structure (for meta data) and importing it into
@@ -1679,8 +1709,9 @@ scan_file_or_directory (struct MainPublishingDialogContext *ctx,
     gtk_builder_get_object (adcc->progress_dialog_builder,
                             "GNUNET_FS_GTK_progress_dialog_textview"));
   adcc->textview_vertical_adjustment = GTK_ADJUSTMENT (gtk_builder_get_object (
-    adcc->progress_dialog_builder,
-    "GNUNET_FS_GTK_progress_dialog_textview_vertical_adjustment"));
+                                                         adcc->
+                                                         progress_dialog_builder,
+                                                         "GNUNET_FS_GTK_progress_dialog_textview_vertical_adjustment"));
   adcc->progress_dialog_textbuffer = GTK_TEXT_BUFFER (
     gtk_builder_get_object (adcc->progress_dialog_builder,
                             "GNUNET_FS_GTK_progress_dialog_textbuffer"));
@@ -1702,6 +1733,7 @@ scan_file_or_directory (struct MainPublishingDialogContext *ctx,
   update_selectivity_execute_cancel (ctx);
 }
 
+
 /**
  * Function called when the "open" (directory) dialog was closed.
  *
@@ -1734,24 +1766,25 @@ GNUNET_GTK_publish_directory_dialog_response_cb (GtkDialog *dialog,
     }
     bo.content_priority =
       gtk_spin_button_get_value (GTK_SPIN_BUTTON (gtk_builder_get_object (
-        ctx->open_directory_builder,
-        "GNUNET_GTK_publish_directory_dialog_priority_spin_button")));
+                                                    ctx->open_directory_builder,
+                                                    "GNUNET_GTK_publish_directory_dialog_priority_spin_button")));
     bo.replication_level =
       gtk_spin_button_get_value (GTK_SPIN_BUTTON (gtk_builder_get_object (
-        ctx->open_directory_builder,
-        "GNUNET_GTK_publish_directory_dialog_replication_spin_button")));
+                                                    ctx->open_directory_builder,
+                                                    "GNUNET_GTK_publish_directory_dialog_replication_spin_button")));
     {
       GtkSpinButton *sb;
 
       sb = GTK_SPIN_BUTTON (gtk_builder_get_object (
-        ctx->open_directory_builder,
-        "GNUNET_GTK_publish_directory_dialog_expiration_year_spin_button"));
+                              ctx->open_directory_builder,
+                              "GNUNET_GTK_publish_directory_dialog_expiration_year_spin_button"));
       bo.expiration_time = GNUNET_GTK_get_expiration_time (sb);
     }
     do_index =
       gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (gtk_builder_get_object (
-        ctx->open_directory_builder,
-        "GNUNET_GTK_publish_directory_dialog_do_index_checkbutton")));
+                                                         ctx->
+                                                         open_directory_builder,
+                                                         "GNUNET_GTK_publish_directory_dialog_do_index_checkbutton")));
     scan_file_or_directory (ctx, filename, &bo, do_index);
     g_free (filename);
   }
@@ -1760,6 +1793,7 @@ GNUNET_GTK_publish_directory_dialog_response_cb (GtkDialog *dialog,
   ctx->open_directory_builder = NULL;
 }
 
+
 /**
  * Function called when the "open" (file) dialog was closed.
  *
@@ -1792,24 +1826,24 @@ GNUNET_GTK_publish_file_dialog_response_cb (GtkDialog *dialog,
     }
     bo.content_priority =
       gtk_spin_button_get_value (GTK_SPIN_BUTTON (gtk_builder_get_object (
-        ctx->open_file_builder,
-        "GNUNET_GTK_publish_file_dialog_priority_spin_button")));
+                                                    ctx->open_file_builder,
+                                                    "GNUNET_GTK_publish_file_dialog_priority_spin_button")));
     {
       GtkSpinButton *sb;
 
       sb = GTK_SPIN_BUTTON (gtk_builder_get_object (
-        ctx->open_file_builder,
-        "GNUNET_GTK_publish_file_dialog_expiration_year_spin_button"));
+                              ctx->open_file_builder,
+                              "GNUNET_GTK_publish_file_dialog_expiration_year_spin_button"));
       bo.expiration_time = GNUNET_GTK_get_expiration_time (sb);
     }
     bo.replication_level =
       gtk_spin_button_get_value (GTK_SPIN_BUTTON (gtk_builder_get_object (
-        ctx->open_file_builder,
-        "GNUNET_GTK_publish_file_dialog_replication_spin_button")));
+                                                    ctx->open_file_builder,
+                                                    "GNUNET_GTK_publish_file_dialog_replication_spin_button")));
     do_index =
       gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (gtk_builder_get_object (
-        ctx->open_file_builder,
-        "GNUNET_GTK_publish_file_dialog_do_index_checkbutton")));
+                                                         ctx->open_file_builder,
+                                                         "GNUNET_GTK_publish_file_dialog_do_index_checkbutton")));
 
     scan_file_or_directory (ctx, filename, &bo, do_index);
     g_free (filename);
@@ -1819,6 +1853,7 @@ GNUNET_GTK_publish_file_dialog_response_cb (GtkDialog *dialog,
   ctx->open_file_builder = NULL;
 }
 
+
 /**
  * User clicked on the 'add' button in the master publish dialog.
  * Create the dialog to allow the user to select a file to add.
@@ -1842,18 +1877,18 @@ GNUNET_GTK_master_publish_dialog_add_button_clicked_cb (GtkWidget *dummy,
    * TRUE */
   gtk_spin_button_set_value (
     GTK_SPIN_BUTTON (gtk_builder_get_object (
-      ctx->open_file_builder,
-      "GNUNET_GTK_publish_file_dialog_priority_spin_button")),
+                       ctx->open_file_builder,
+                       "GNUNET_GTK_publish_file_dialog_priority_spin_button")),
     1000);
   gtk_spin_button_set_value (
     GTK_SPIN_BUTTON (gtk_builder_get_object (
-      ctx->open_file_builder,
-      "GNUNET_GTK_publish_file_dialog_replication_spin_button")),
+                       ctx->open_file_builder,
+                       "GNUNET_GTK_publish_file_dialog_replication_spin_button")),
     0);
   gtk_toggle_button_set_active (
     GTK_TOGGLE_BUTTON (gtk_builder_get_object (
-      ctx->open_file_builder,
-      "GNUNET_GTK_publish_file_dialog_do_index_checkbutton")),
+                         ctx->open_file_builder,
+                         "GNUNET_GTK_publish_file_dialog_do_index_checkbutton")),
     TRUE);
 
   {
@@ -1877,6 +1912,7 @@ GNUNET_GTK_master_publish_dialog_add_button_clicked_cb (GtkWidget *dummy,
   }
 }
 
+
 /**
  * User clicked on the 'open' button in the master publish dialog.
  * Create the dialog to allow the user to select a directory.
@@ -1901,26 +1937,26 @@ GNUNET_GTK_master_publish_dialog_open_button_clicked_cb (GtkWidget *dummy,
    * TRUE */
   gtk_spin_button_set_value (
     GTK_SPIN_BUTTON (gtk_builder_get_object (
-      ctx->open_directory_builder,
-      "GNUNET_GTK_publish_directory_dialog_priority_spin_button")),
+                       ctx->open_directory_builder,
+                       "GNUNET_GTK_publish_directory_dialog_priority_spin_button")),
     1000);
   gtk_spin_button_set_value (
     GTK_SPIN_BUTTON (gtk_builder_get_object (
-      ctx->open_directory_builder,
-      "GNUNET_GTK_publish_directory_dialog_replication_spin_button")),
+                       ctx->open_directory_builder,
+                       "GNUNET_GTK_publish_directory_dialog_replication_spin_button")),
     0);
   gtk_toggle_button_set_active (
     GTK_TOGGLE_BUTTON (gtk_builder_get_object (
-      ctx->open_directory_builder,
-      "GNUNET_GTK_publish_directory_dialog_do_index_checkbutton")),
+                         ctx->open_directory_builder,
+                         "GNUNET_GTK_publish_directory_dialog_do_index_checkbutton")),
     TRUE);
 
   {
     GtkComboBox *combo;
 
     combo = GTK_COMBO_BOX (gtk_builder_get_object (
-      ctx->open_directory_builder,
-      "GNUNET_GTK_publish_directory_dialog_anonymity_combobox"));
+                             ctx->open_directory_builder,
+                             "GNUNET_GTK_publish_directory_dialog_anonymity_combobox"));
     gtk_combo_box_set_model (combo,
                              GNUNET_FS_GTK_get_anonymity_level_list_store ());
   }
@@ -1937,6 +1973,7 @@ GNUNET_GTK_master_publish_dialog_open_button_clicked_cb (GtkWidget *dummy,
   }
 }
 
+
 /* ********************************* editing sub-dialog ********************* */
 
 /**
@@ -2013,6 +2050,7 @@ update_treeview_after_edit (void *cls,
   return GNUNET_SYSERR;
 }
 
+
 /**
  * Function called when the edit publish dialog has been closed.
  *
@@ -2032,6 +2070,7 @@ master_publish_edit_publish_dialog_cb (gpointer cls, gint ret, const char *root)
   GNUNET_free (epc);
 }
 
+
 /**
  * The user clicked on the "edit" button in the master dialog.  Edit
  * the selected tree item.
@@ -2068,6 +2107,7 @@ GNUNET_GTK_master_publish_dialog_edit_button_clicked_cb (GtkWidget *dummy,
                                      epc);
 }
 
+
 /* ******************** master edit dialog shutdown *********************** */
 
 /**
@@ -2105,6 +2145,7 @@ get_file_information (GtkTreeModel *tm, GtkTreeIter *iter)
   return fi;
 }
 
+
 /**
  * Recursively clean up the tree store with the file information in it.
  *
@@ -2130,6 +2171,7 @@ free_file_information_tree_store (GtkTreeModel *tm, GtkTreeIter *iter)
   }
 }
 
+
 /**
  * Close the master publish dialog.  If the response code was OK, starts
  * the publishing operation.  Otherwise, this function just cleans up the
@@ -2167,6 +2209,7 @@ close_master_publish_dialog (struct MainPublishingDialogContext *ctx)
   return GNUNET_YES;
 }
 
+
 /**
  * Insert namespace advertisement into metadata when
  * publishing in both private namespace and global namespace.
@@ -2203,7 +2246,13 @@ insert_advertisement (void *cls,
   if (NULL == ctx->ns)
     return GNUNET_SYSERR;
   GNUNET_IDENTITY_ego_get_public_key (ctx->ns, &pub);
-  sks_uri = GNUNET_FS_uri_sks_create (&pub, "/");
+  if (GNUNET_IDENTITY_TYPE_ECDSA != pub.type)
+  {
+    GNUNET_break (0); /* FIXME: EDDSA keys not yet
+                         supported for file-sharing! */
+    return GNUNET_SYSERR;
+  }
+  sks_uri = GNUNET_FS_uri_sks_create (&pub.ecdsa_key, "/");
   sks_uri_string = GNUNET_FS_uri_to_string (sks_uri);
   GNUNET_FS_uri_destroy (sks_uri);
   if (NULL == sks_uri_string)
@@ -2220,6 +2269,7 @@ insert_advertisement (void *cls,
   return GNUNET_SYSERR;
 }
 
+
 /**
  * The user pushed the 'execute' button.  Start the publishing
  * operation and clean up the memory and the window itself.
@@ -2308,14 +2358,29 @@ GNUNET_GTK_master_publish_dialog_execute_button_clicked_cb (GtkButton *button,
       clear_keywords_from_tm (ctx);
     do
     {
+      const struct GNUNET_IDENTITY_PrivateKey *pk;
+
+      if (NULL != ns)
+      {
+        pk = GNUNET_IDENTITY_ego_get_private_key (ns);
+        if (GNUNET_IDENTITY_TYPE_ECDSA != pk->type)
+        {
+          GNUNET_break (0); /* FIXME: EDDSA keys not yet supported by FS */
+          gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ctx->own_checkbox),
+                                        FALSE);
+          return;
+        }
+      }
+      else
+      {
+        pk = NULL;
+      }
       fi = get_file_information (ctx->file_info_treemodel, &iter);
       if (do_global && do_own && ! disable_ads_insertion)
         GNUNET_FS_file_information_inspect (fi, insert_advertisement, ctx);
       GNUNET_FS_publish_start (GNUNET_FS_GTK_get_fs_handle (),
                                fi,
-                               (NULL == ns)
-                                 ? NULL
-                                 : GNUNET_IDENTITY_ego_get_private_key (ns),
+                               (NULL == pk) ? NULL : &pk->ecdsa_key,
                                namespace_id,
                                namespace_uid,
                                GNUNET_FS_PUBLISH_OPTION_NONE);
@@ -2330,6 +2395,7 @@ GNUNET_GTK_master_publish_dialog_execute_button_clicked_cb (GtkButton *button,
   GNUNET_break (GNUNET_YES == close_master_publish_dialog (ctx));
 }
 
+
 /**
  * Function called on entries in a `struct GNUNET_FS_FileInformation` for
  * publishing.
@@ -2363,6 +2429,7 @@ clear_keywords_in_file_information (void *cls,
   return GNUNET_OK;
 }
 
+
 /**
  * Remove all of the keywords from the file information item in the tree store
  *
@@ -2393,6 +2460,7 @@ clear_keywords_from_file_information_in_tree_store (GtkTreeModel *tm,
   }
 }
 
+
 /**
  * Remove all of the keywords from all file information structs in the tree
  * store
@@ -2409,11 +2477,12 @@ clear_keywords_from_tm (struct MainPublishingDialogContext *ctx)
     do
     {
       clear_keywords_from_file_information_in_tree_store (ctx
-                                                            ->file_info_treemodel,
+                                                          ->file_info_treemodel,
                                                           &iter);
     } while (gtk_tree_model_iter_next (ctx->file_info_treemodel, &iter));
 }
 
+
 /**
  * The user pushed the 'clear' button.  Remove all keywords.
  *
@@ -2427,6 +2496,7 @@ GNUNET_GTK_master_publish_dialog_clear_button_clicked_cb (GtkButton *button,
   clear_keywords_from_tm (user_data);
 }
 
+
 /**
  * The user pushed the 'cancel' button.  Close the master publish dialog.
  *
@@ -2442,6 +2512,7 @@ GNUNET_GTK_master_publish_dialog_cancel_button_clicked_cb (GtkButton *button,
   GNUNET_break (GNUNET_YES == close_master_publish_dialog (ctx));
 }
 
+
 /**
  * The user attempted to close the publish window.  Check if this is
  * allowed and if so, close it.
@@ -2464,6 +2535,7 @@ GNUNET_GTK_master_publish_dialog_delete_event_cb (GtkWidget *widget,
   return FALSE;
 }
 
+
 /**
  * Called when expander changes its state (expanded/hidden).
  * Hides the widget, adjusts the paned position to compensate,
@@ -2501,6 +2573,7 @@ expander_callback (GObject *object, GParamSpec *param_spec, gpointer user_data)
   gtk_paned_set_position (GTK_PANED (ctx->vpaned), paned_pos);
 }
 
+
 /* ******************** master edit dialog initialization ******************* */
 
 /**
@@ -2676,7 +2749,8 @@ add_updateable_to_ts (void *cls,
   }
   g_free (displaytext);
 
-  if (NULL == spath)
+  if (NULL != spath)
+    return;
   {
     GtkTreePath *path;
     char *gspath;
@@ -2687,26 +2761,33 @@ add_updateable_to_ts (void *cls,
      * map */
     gspath = GNUNET_strdup (spath);
     if (GNUNET_SYSERR == GNUNET_CONTAINER_multihashmap_put (
-                           uc->seen,
-                           &hc,
-                           gspath,
-                           GNUNET_CONTAINER_MULTIHASHMAPOPTION_UNIQUE_FAST))
+          uc->seen,
+          &hc,
+          gspath,
+          GNUNET_CONTAINER_MULTIHASHMAPOPTION_UNIQUE_FAST))
       GNUNET_free (gspath);
   }
-  else
-    return;
 
   sc.parent = &iter;
   sc.ts = uc->ts;
   sc.ns = uc->ns;
   sc.seen = uc->seen;
   sc.update_called = GNUNET_NO;
-  GNUNET_FS_namespace_list_updateable (GNUNET_FS_GTK_get_fs_handle (),
-                                       GNUNET_IDENTITY_ego_get_private_key (
-                                         uc->ns),
-                                       next_id,
-                                       &add_updateable_to_ts,
-                                       &sc);
+  {
+    const struct GNUNET_IDENTITY_PrivateKey *pk;
+
+    pk = GNUNET_IDENTITY_ego_get_private_key (uc->ns);
+    if (GNUNET_IDENTITY_TYPE_ECDSA != pk->type)
+    {
+      GNUNET_break (0);
+      return;
+    }
+    GNUNET_FS_namespace_list_updateable (GNUNET_FS_GTK_get_fs_handle (),
+                                         &pk->ecdsa_key,
+                                         next_id,
+                                         &add_updateable_to_ts,
+                                         &sc);
+  }
   if ((sc.update_called == GNUNET_NO) && (NULL != next_id) &&
       (strlen (next_id) > 0))
   {
@@ -2731,6 +2812,7 @@ add_updateable_to_ts (void *cls,
   }
 }
 
+
 /**
  * Called by a hashmap iterator.
  * Frees its argument with GNUNET_free().
@@ -2747,6 +2829,7 @@ free_seen_paths (void *cls, const struct GNUNET_HashCode *key, void *value)
   return GNUNET_YES;
 }
 
+
 /**
  * User changed the selected namespace.  Check if it is valid,
  * and if so, update the rest of the dialog accordingly.
@@ -2798,13 +2881,25 @@ GNUNET_GTK_master_publish_dialog_ego_combobox_changed_cb (GtkComboBox *combo,
   uc.ns = ego;
   uc.update_called = GNUNET_NO;
   uc.seen = GNUNET_CONTAINER_multihashmap_create (128, GNUNET_NO);
+  {
+    const struct GNUNET_IDENTITY_PrivateKey *pk;
 
-  GNUNET_FS_namespace_list_updateable (GNUNET_FS_GTK_get_fs_handle (),
-                                       GNUNET_IDENTITY_ego_get_private_key (
-                                         ego),
-                                       NULL,
-                                       &add_updateable_to_ts,
-                                       &uc);
+    pk = GNUNET_IDENTITY_ego_get_private_key (ego);
+    if (GNUNET_IDENTITY_TYPE_ECDSA != pk->type)
+    {
+      GNUNET_break (0);
+      gtk_widget_set_sensitive (ctx->identifier_entry, FALSE);
+      gtk_widget_set_sensitive (ctx->updateable_checkbox, FALSE);
+      gtk_widget_set_sensitive (ctx->update_id_entry, FALSE);
+      update_selectivity_execute_cancel (ctx);
+      return;
+    }
+    GNUNET_FS_namespace_list_updateable (GNUNET_FS_GTK_get_fs_handle (),
+                                         &pk->ecdsa_key,
+                                         NULL,
+                                         &add_updateable_to_ts,
+                                         &uc);
+  }
   GNUNET_CONTAINER_multihashmap_iterate (uc.seen, &free_seen_paths, NULL);
   GNUNET_CONTAINER_multihashmap_destroy (uc.seen);
   gtk_widget_set_sensitive (ctx->identifier_entry, TRUE);
@@ -2813,6 +2908,7 @@ GNUNET_GTK_master_publish_dialog_ego_combobox_changed_cb (GtkComboBox *combo,
   update_selectivity_execute_cancel (ctx);
 }
 
+
 /**
  * Add all updateable entries of the current namespace to the
  * tree store.
@@ -2883,6 +2979,7 @@ add_namespace_to_ts (void *cls,
   gtk_widget_set_sensitive (ctx->update_id_entry, have_ns);
 }
 
+
 /**
  * Run the file-publishing operation (by opening the master publishing dialog).
  *
@@ -2936,8 +3033,8 @@ GNUNET_GTK_main_menu_file_publish_activate_cb (GtkWidget *dummy,
     gtk_builder_get_object (ctx->builder,
                             "GNUNET_GTK_master_publish_dialog_cancel_button"));
   ctx->file_info_treeview = GTK_TREE_VIEW (gtk_builder_get_object (
-    ctx->builder,
-    "GNUNET_GTK_master_publish_dialog_file_information_tree_view"));
+                                             ctx->builder,
+                                             "GNUNET_GTK_master_publish_dialog_file_information_tree_view"));
   ctx->file_info_selection =
     gtk_tree_view_get_selection (ctx->file_info_treeview);
   ctx->file_info_treemodel = gtk_tree_view_get_model (ctx->file_info_treeview);
@@ -2951,8 +3048,8 @@ GNUNET_GTK_main_menu_file_publish_activate_cb (GtkWidget *dummy,
     gtk_builder_get_object (ctx->builder,
                             "GNUNET_GTK_master_publish_dialog_own_checkbox"));
   ctx->updateable_checkbox = GTK_WIDGET (gtk_builder_get_object (
-    ctx->builder,
-    "GNUNET_GTK_master_publish_dialog_updateable_checkbox"));
+                                           ctx->builder,
+                                           "GNUNET_GTK_master_publish_dialog_updateable_checkbox"));
   ctx->update_id_entry = GTK_WIDGET (
     gtk_builder_get_object (ctx->builder,
                             "GNUNET_GTK_master_publish_dialog_update_id_entry"));
@@ -2965,8 +3062,8 @@ GNUNET_GTK_main_menu_file_publish_activate_cb (GtkWidget *dummy,
                             "GNUNET_GTK_master_publish_dialog_update_id_hbox"));
 
   ctx->identifiers_expander = GTK_WIDGET (gtk_builder_get_object (
-    ctx->builder,
-    "GNUNET_GTK_master_publish_dialog_previous_identifiers_expander"));
+                                            ctx->builder,
+                                            "GNUNET_GTK_master_publish_dialog_previous_identifiers_expander"));
   ctx->vpaned = GTK_WIDGET (
     gtk_builder_get_object (ctx->builder,
                             "GNUNET_GTK_master_publish_dialog_vpaned"));
@@ -2978,11 +3075,11 @@ GNUNET_GTK_main_menu_file_publish_activate_cb (GtkWidget *dummy,
     gtk_builder_get_object (ctx->builder,
                             "GNUNET_GTK_master_publish_dialog_identifier_entry"));
   ctx->identifiers_scrolled = GTK_WIDGET (gtk_builder_get_object (
-    ctx->builder,
-    "GNUNET_GTK_master_publish_dialog_previous_identifiers_scrolled"));
+                                            ctx->builder,
+                                            "GNUNET_GTK_master_publish_dialog_previous_identifiers_scrolled"));
   ctx->identifiers_treeview = GTK_TREE_VIEW (gtk_builder_get_object (
-    ctx->builder,
-    "GNUNET_GTK_master_publish_dialog_previous_identifiers_treeview"));
+                                               ctx->builder,
+                                               "GNUNET_GTK_master_publish_dialog_previous_identifiers_treeview"));
   ctx->identifiers_treemodel =
     gtk_tree_view_get_model (ctx->identifiers_treeview);
   ctx->identifiers_selection =
@@ -3033,4 +3130,5 @@ GNUNET_GTK_main_menu_file_publish_activate_cb (GtkWidget *dummy,
   gtk_window_present (GTK_WINDOW (ctx->master_pubdialog));
 }
 
+
 /* end of gnunet-fs-gtk_publish-dialog.c */
