@@ -539,7 +539,7 @@ GNUNET_GTK_edit_publication_metadata_tree_view_value_renderer_edited_cb (
                       PUBLISH_METADATA_MC_VALUE,
                       ivalue,
                       -1);
-  GNUNET_free_non_null (avalue);
+  GNUNET_free (avalue);
 }
 
 
@@ -1141,7 +1141,7 @@ file_information_update (void *cls,
                                          mime,
                                          data,
                                          data_size);
-      GNUNET_free_non_null (mime);
+      GNUNET_free (mime);
     }
     g_object_unref (f);
     g_free (fn);
