@@ -54,16 +54,6 @@ struct GNUNET_GTK_MainLoop;
 
 /* ****************** Initialization *************** */
 
-/**
- * If desired, enable plugging of this main window in the meta window.
- *
- * @param env_name environment variable to check
- * @param main_window main window to plug
- * @return new main window to initialize
- */
-GtkWidget *
-GNUNET_GTK_plug_me (const char *env_name, GtkWidget *main_window);
-
 
 /**
  * Initialize natural language support.
@@ -91,7 +81,8 @@ GNUNET_GTK_get_data_dir (void);
 
 /**
  * @brief get the path to a specific GNUnet installation directory or,
- * with #GNUNET_OS_IPK_SELF_PREFIX, the current running apps installation directory
+ * with #GNUNET_OS_IPK_SELF_PREFIX, the current running apps installation
+ * directory
  * @author Milan
  *
  * @param dirkind which directory should be returned
@@ -202,8 +193,10 @@ GNUNET_FS_GTK_remove_treestore_subtree (GtkTreeStore *ts, GtkTreeIter *root);
  * @param argv command line options
  * @param options allowed command line options
  * @param main_window_file glade file for the main window
- * @param main_task first task to run, closure will be set to the `struct GNUNET_GTK_MainLoop`
- * @return #GNUNET_OK on success, #GNUNET_SYSERR on error (i.e. bad command-line options, etc)
+ * @param main_task first task to run, closure will be set to the `struct
+ * GNUNET_GTK_MainLoop`
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR on error (i.e. bad command-line
+ * options, etc)
  */
 int
 GNUNET_GTK_main_loop_start (const char *binary_name,
