@@ -112,10 +112,14 @@ GNUNET_GTK_get_new_builder2 (const char *filename,
   GError *error;
 
   ret = gtk_builder_new ();
-  gtk_builder_set_translation_domain (ret, "gnunet-gtk");
-  GNUNET_asprintf (&glade_path, "%s%s", GNUNET_GTK_get_data_dir (), filename);
+  GNUNET_asprintf (&glade_path,
+                   "%s%s",
+                   GNUNET_GTK_get_data_dir (),
+                   filename);
   error = NULL;
-  if (0 == gtk_builder_add_from_file (ret, glade_path, &error))
+  if (0 == gtk_builder_add_from_file (ret,
+                                      glade_path,
+                                      &error))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                 _ ("Failed to load `%s': %s\n"),
