@@ -36,18 +36,19 @@
  * @param user_data not used
  */
 void
-GNUNET_setup_hostlist_url_cellrenderertext_edited_cb (GtkCellRendererText *renderer,
-                                                      gchar * path,
-                                                      gchar * new_text,
-                                                      gpointer user_data)
+GNUNET_setup_hostlist_url_cellrenderertext_edited_cb (
+  GtkCellRendererText *renderer,
+  gchar *path,
+  gchar *new_text,
+  gpointer user_data)
 {
   GtkListStore *ls;
   GtkTreeIter old;
   GtkTreeIter iter;
   gchar *oldtext;
 
-  ls = GTK_LIST_STORE (GNUNET_SETUP_get_object
-                       ("GNUNET_setup_hostlist_url_liststore"));
+  ls = GTK_LIST_STORE (
+    GNUNET_SETUP_get_object ("GNUNET_setup_hostlist_url_liststore"));
   if (NULL == ls)
   {
     GNUNET_break (0);
@@ -58,22 +59,30 @@ GNUNET_setup_hostlist_url_cellrenderertext_edited_cb (GtkCellRendererText *rende
     GNUNET_break (0);
     return;
   }
-  gtk_tree_model_get (GTK_TREE_MODEL (ls), &old,
-                      GNUNET_GTK_SETUP_HOSTLIST_URL_MC_URL, &oldtext,
+  gtk_tree_model_get (GTK_TREE_MODEL (ls),
+                      &old,
+                      GNUNET_GTK_SETUP_HOSTLIST_URL_MC_URL,
+                      &oldtext,
                       -1);
   if (0 == strlen (oldtext))
   {
     gtk_list_store_insert_before (ls, &iter, &old);
-    gtk_list_store_set (ls, &iter,
-                        GNUNET_GTK_SETUP_HOSTLIST_URL_MC_URL, new_text,
-                        GNUNET_GTK_SETUP_HOSTLIST_URL_MC_EDITABLE, FALSE,
+    gtk_list_store_set (ls,
+                        &iter,
+                        GNUNET_GTK_SETUP_HOSTLIST_URL_MC_URL,
+                        new_text,
+                        GNUNET_GTK_SETUP_HOSTLIST_URL_MC_EDITABLE,
+                        FALSE,
                         -1);
   }
   else
   {
-    gtk_list_store_set (ls, &old,
-                        GNUNET_GTK_SETUP_HOSTLIST_URL_MC_URL, new_text,
-                        GNUNET_GTK_SETUP_HOSTLIST_URL_MC_EDITABLE, FALSE,
+    gtk_list_store_set (ls,
+                        &old,
+                        GNUNET_GTK_SETUP_HOSTLIST_URL_MC_URL,
+                        new_text,
+                        GNUNET_GTK_SETUP_HOSTLIST_URL_MC_EDITABLE,
+                        FALSE,
                         -1);
   }
   g_free (oldtext);
